@@ -17,7 +17,16 @@ TEMPLATE = '''
         [...document.getElementsByTagName('textarea')].forEach(e => {
             if (e.className === 'form-control') {
                 e.classList.add('simplemde-attached');
-                setTimeout(() => new SimpleMDE({ element: e }));
+                let editor = new SimpleMDE({ element: e });
+                editor.codemirror.on('change', () => {
+                    // update textarea value
+                    e.value = editor.value();
+
+                    // dispatch syntetic event for react to update its state
+                    let ev = new Event('input', { bubbles: true });
+                    ev.simulated = true;
+                    e.dispatchEvent(ev);
+                });
             };
         });
     })).observe(
@@ -43,15 +52,18 @@ def get_description(mod):
     return email.message_from_string(meta).get('Summary', None)
 
 
+def patched_endpoint(self, *args, **kwargs):
+    return render_template_string(TEMPLATE)
+
+
 class SimpleMdePlugin(Plugin):
     name = 'SimpleMDE'
     description = get_description(__module__)
 
-    def patched_endpoint(self, *args, **kwargs):
-        return render_template_string(TEMPLATE)
-
-    def on_server_spawn(self, **kwargs):
+    def on_server_spawn(self, *args, **kwargs):
+        # remove all rule besides first one which is edit redirect
         while len(dash.bp.deferred_functions) > 1:
             dash.bp.deferred_functions.pop()
+        # ... and fill all the rules back with our wrapper template
         for path, endpoint in dash.endpoints:
-            dash.bp.add_url_rule(path, endpoint, self.patched_endpoint)
+            dash.bp.add_url_rule(path, endpoint, patched_endpoint)
